@@ -1,21 +1,23 @@
-#' Computes the sequence of patterns, means, variances, covariance and correlation
+#' Computes the collection of patterns, means, variances, covariance and correlation
 #' matrices for a given dataset with missing values.
 #'
 #' Using the same the notation of  \insertCite{BB2024;textual}{MCARtest}, computes
-#' the sequence of patterns \eqn{\mathbb{S}}, means \eqn{\mu_\mathbb{S}}, variances
-#' \eqn{\sigma^2_\mathbb{S}}, and correlation matrices \eqn{\Sigma_\mathbb{S}}
-#' for a dataset with missing values.
+#' the collection of patterns \eqn{\mathbb{S}}, means \eqn{\mu_\mathbb{S}}, variances
+#' \eqn{\sigma^2_\mathbb{S}}, covariance matrices \eqn{\Omega_\mathbb{S}}
+#' and correlation matrices \eqn{\Sigma_\mathbb{S}} for a dataset with missing values.
 #'
 #' @param X The dataset with incomplete data.
+#' @param min_diff A natural number such that patterns with \eqn{n_S \leq |S| + min_diff} 
+#' are discarded. Default to zero.
 #'
 #'
-#' @returns \code{patterns} The sequence of patterns \eqn{\mathbb{S}}.
+#' @returns \code{patterns} The collection of patterns \eqn{\mathbb{S}}.
 #' @returns \code{n_pattern} The cardinality of \eqn{\mathbb{S}}.
 #' @returns \code{data_pattern} A vector where the data are grouped according to \eqn{\mathbb{S}}.
-#' @returns \code{muS} The sequence of means.
-#' @returns \code{C_S} The sequence of covariance matrices.
-#' @returns \code{sigma_squared_S} The sequence of variances.
-#' @returns \code{SigmaS} The sequence of correlation matrices.
+#' @returns \code{mu_S} The collection of means.
+#' @returns \code{C_S} The collection of covariance matrices.
+#' @returns \code{sigma_squared_S} The collection of variances.
+#' @returns \code{SigmaS} The collection of correlation matrices.
 #' @returns \code{ambient_dimension} The dimension \eqn{d} of the data.
 #'
 #' @references \insertRef{BB2024}{MCARtest}
@@ -26,7 +28,7 @@
 #' @examples
 #' library(copula)
 #' library(missMethods)
-#' n = 1000
+#' n = 100
 #'
 #' cp = claytonCopula(param = c(1), dim = 5)
 #' P = mvdc(copula = cp, margins = c("exp", "exp", "exp", "exp", "exp"),
@@ -35,8 +37,9 @@
 #' X = delete_MCAR(X, 0.1, c(1,4,5))
 #'
 #' get_SigmaS(X)
+#' get_SigmaS(X, min_diff = 20)
 
-get_SigmaS = function(X){
+get_SigmaS = function(X, min_diff = 0){
 
   #### create vector with indicators of NA's
   d = dim(X)[2]
@@ -44,7 +47,7 @@ get_SigmaS = function(X){
   pattern_indicator = unique(apply(X, 2L, function(y) as.numeric(1-is.na(y))))
   n_pattern = dim(pattern_indicator)[1]
 
-  ### create sequence of patterns e.g. c(2,3) if d=3 and just X1 is missing
+  ### create collection of patterns e.g. c(2,3) if d=3 and just X1 is missing
   patterns = list()
   for (row in 1:n_pattern){
     patterns[[row]] = v[as.logical(pattern_indicator[row,])]
@@ -68,7 +71,7 @@ get_SigmaS = function(X){
 
   deletion = c()
   for (i in 1:n_pattern){
-    if (dim(data_pattern[[i]])[1] <= dim(data_pattern[[i]])[2]){ ####### remove pattern with sample size too small
+    if (dim(data_pattern[[i]])[1] <= dim(data_pattern[[i]])[2] + min_diff){ ####### remove pattern with sample size too small
       print("Warning: Some patterns were deleted because the sample size was too small!")
       deletion = c(deletion, i)
     }
@@ -93,7 +96,7 @@ get_SigmaS = function(X){
   }
 
   my_list = list("patterns" = patterns, "n_pattern" = n_pattern,
-                 "data_pattern" = data_pattern, "muS" = muS,
+                 "data_pattern" = data_pattern, "mu_S" = muS,
                  "C_S" = C_S, "sigma_squared_S" = sigma_squared_S,
                  "SigmaS" = SigmaS, "ambient_dimension" = d)
   return(my_list)
